:mod:`~arcs.gsi.proxy` -- Handle certificate proxies
===================================================

.. _ref-proxy

.. module:: arcs.gsi.proxy
.. moduleauthor:: Russell Sim <russell@vpac.org>


:class:`ProxyCertificate` Objects
---------------------------------
.. autoclass:: ProxyCertificate
   :members:
   :undoc-members:


.. seealso::

    Class :class:`~arcs.gsi.certificate.Certificate`
        a class that is used to handle certificates

    Class :class:`~arcs.gsi.key.Key`
        a class that is used by the certificate classes to handle the key pairs

